@@ -288,7 +288,9 @@ class NodeGraphicsItem(graphic_type):
                                    QtGui.QPainter.TextAntialiasing |
                                    QtGui.QPainter.SmoothPixmapTransform)
         else:
-            painter.setRenderHints(False)
+            painter.setRenderHints(QtGui.QPainter.Antialiasing |
+                                   QtGui.QPainter.TextAntialiasing |
+                                   QtGui.QPainter.SmoothPixmapTransform, False)
         self.draw_title(painter, lod)
         self.draw_attributes(painter, lod)
         self.draw_border(painter, lod)
@@ -335,6 +337,10 @@ class NodeGraphicsItem(graphic_type):
         painter.setPen(QtCore.Qt.NoPen)
         bg = painter.background()
         bgm = painter.backgroundMode()
+        if self.error_item:
+            self.scene().removeItem(self.error_item)
+            self.error_item.deleteLater()
+        self.error_item = None
         if self.is_real:
             painter.setBackgroundMode(QtCore.Qt.OpaqueMode)
         else:
@@ -471,11 +477,6 @@ class NodeGraphicsItem(graphic_type):
                 error_item.setParentItem(self)
                 error_item.setZValue(50)
                 self.error_item = error_item
-            else:
-                if self.error_item:
-                    self.scene().removeItem(self.error_item)
-                    self.error_item.deleteLater()
-                self.error_item = None
 
         # draw collapse state arrow
         for arrow in self.collapse_arrows:
@@ -972,7 +973,9 @@ class NodeGraphicsPlug(QtWidgets.QGraphicsItem):
                                    QtGui.QPainter.TextAntialiasing |
                                    QtGui.QPainter.SmoothPixmapTransform)
         else:
-            painter.setRenderHints(False)
+            painter.setRenderHints(QtGui.QPainter.Antialiasing |
+                                   QtGui.QPainter.TextAntialiasing |
+                                   QtGui.QPainter.SmoothPixmapTransform, False)
         if self.is_hovered:
             painter.setPen(QtGui.QPen(QtCore.Qt.white, self.hover_width, QtCore.Qt.SolidLine, QtCore.Qt.RoundCap, QtCore.Qt.RoundJoin))
         else:
@@ -1151,11 +1154,12 @@ class ErrorItem(QtWidgets.QGraphicsTextItem):
         return QtCore.QRectF(-10, -10, 10, 10)
 
     def paint(self, painter, option, widget):
-        painter.setRenderHints(QtGui.QPainter.Antialiasing | QtGui.QPainter.TextAntialiasing)
+        painter.setRenderHints(QtGui.QPainter.Antialiasing |
+                               QtGui.QPainter.TextAntialiasing)
         painter.setPen(QtCore.Qt.NoPen)
         painter.setBrush(colors.ERROR)
         painter.drawEllipse(0, 0, 20, 20)
         painter.setPen(QtCore.Qt.black)
         painter.setFont(self.font())
-        painter.setCompositionMode(QtGui.QPainter.CompositionMode_SourceOut)
-        painter.drawText(QtCore.QRectF(0.6, 0.1, 20, 20), QtCore.Qt.AlignCenter, self.text)
+        painter.drawText(QtCore.QRectF(0.6, 0.1, 20, 20), QtCore.Qt.AlignCenter,
+                         self.text)
